@@ -1,6 +1,6 @@
 (*---------------------------------------------------------------------------
    Copyright (c) 2015 The ptime programmers. All rights reserved.
-   Distributed under the ISC license, see terms at the end of the file.
+   SPDX-License-Identifier: ISC
   ---------------------------------------------------------------------------*)
 
 (* Julian day and proleptic Gregorian calendar date conversion.
@@ -274,7 +274,7 @@ module Span = struct
     let s, ms = divide_ps ~carry:1000 ps ps_count_in_s ps_count_in_ms in
     if s = 60 then Format.fprintf ppf "%dmin" (if neg then -1 else 1) else
     let s = if neg then -s else s in
-    if ms <> 0 then Format.fprintf ppf "%d.%ds" s ms else
+    if ms <> 0 then Format.fprintf ppf "%d.%03ds" s ms else
     Format.fprintf ppf "%ds" s
 
   let pp_unit higher_str hi hi_str frac_limit lo ppf ~neg ps =
@@ -287,7 +287,7 @@ module Span = struct
       let h, l = divide_ps ~carry:1000 ps hi lo in
       if h >= 100 || l = 0 then pp_unit_integral ppf ~neg h else
       let h = if neg then -h else h in
-      Format.fprintf ppf "%d.%d%s" h l hi_str
+      Format.fprintf ppf "%d.%03d%s" h l hi_str
     end else begin
       let ms, _ = divide_ps ~carry:1 ps hi hi in
       pp_unit_integral ppf ~neg ms
@@ -459,6 +459,9 @@ let to_year ?(tz_offset_s = 0) t =
   in
   jd_to_year (d + jd_posix_epoch)
 
+
+type weekday = [ `Sun | `Mon | `Tue | `Wed | `Thu | `Fri | `Sat ]
+
 let weekday_num ?(tz_offset_s = 0) t =
   let (d, _) = Span.add t (Span.of_int_s tz_offset_s) in
   (* N.B. in contrast to [to_date_time] we don't care if we fall outside
@@ -702,19 +705,3 @@ let pp_human ?frac_s:(frac = 0) ?tz_offset_s () ppf (_, ps as t) =
 
 let pp = pp_human ~tz_offset_s:0 ()
 let dump = Span.dump
-
-(*---------------------------------------------------------------------------
-   Copyright (c) 2015 The ptime programmers
-
-   Permission to use, copy, modify, and/or distribute this software for any
-   purpose with or without fee is hereby granted, provided that the above
-   copyright notice and this permission notice appear in all copies.
-
-   THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
-   WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
-   MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
-   ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
-   WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
-   ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
-   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
-  ---------------------------------------------------------------------------*)
