@@ -1,6 +1,6 @@
 (*---------------------------------------------------------------------------
    Copyright (c) 2015 The ptime programmers. All rights reserved.
-   Distributed under the ISC license, see terms at the end of the file.
+   SPDX-License-Identifier: ISC
   ---------------------------------------------------------------------------*)
 
 (** POSIX time values.
@@ -371,9 +371,10 @@ val to_year : ?tz_offset_s:tz_offset_s -> t -> int
 
 (** {2:weekdays Week days} *)
 
-val weekday :
-  ?tz_offset_s:tz_offset_s -> t ->
-  [ `Sun | `Mon | `Tue | `Wed | `Thu | `Fri | `Sat ]
+type weekday = [ `Sun | `Mon | `Tue | `Wed | `Thu | `Fri | `Sat ]
+(** The type for the days of the 7-day week. *)
+
+val weekday : ?tz_offset_s:tz_offset_s -> t -> weekday
 (** [weekday ~tz_offset_s t] is the day in the 7-day week of timestamp [t]
     expressed in the time zone offset [ts_offset_s] (defaults to [0]). *)
 
@@ -609,20 +610,3 @@ let () = assert (Ptime.equal (get @@ Ptime.add_span t0 one_s) t2)
           measure time spans in a single program run use a monotonic
           time source (e.g. {!Mtime}).}}}}
 *)
-
-
-(*---------------------------------------------------------------------------
-   Copyright (c) 2015 The ptime programmers
-
-   Permission to use, copy, modify, and/or distribute this software for any
-   purpose with or without fee is hereby granted, provided that the above
-   copyright notice and this permission notice appear in all copies.
-
-   THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
-   WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
-   MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
-   ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
-   WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
-   ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
-   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
-  ---------------------------------------------------------------------------*)
